# pylint: disable-msg=W0622
"""cubicweb-book application packaging information"""

modname = "book"
distname = "cubicweb-%s" % modname

numversion = (1, 0, 0)
version = ".".join(str(num) for num in numversion)

license = "LGPL"
description = "component to describe books for the CubicWeb framework"
author = "Logilab"
author_email = "contact@logilab.fr"
long_desc = """
This cube provides the entity type ``Book`` and uses the OpenLibrary API_
to automatically fill the book's description

Check out : `Fetching book descriptions and covers`_

.. _`Fetching book descriptions and covers` : http://www.logilab.org/blogentry/9138
.. _API : http://openlibrary.org/dev/docs/api
"""
web = "https://forge.extranet.logilab.fr/cubicweb/cubes/book"

classifiers = [
    "Environment :: Web Environment",
    "Framework :: CubicWeb",
    "Programming Language :: Python",
    "Programming Language :: JavaScript",
]

__depends__ = {
    "cubicweb": ">=4.0.0,<5.0.0",
    "cubicweb_web": ">=1.0.0,<2.0.0",
    "cubicweb-addressbook": ">=2.0.0,<3.0.0",
    "cubicweb-person": ">=2.0.0,<3.0.0",
    "cubicweb-file": ">=4.0.0,<5.0.0",
}



"""template automatic tests"""

from cubicweb_web.devtools.testlib import AutomaticWebTest, WebCWTC
from cubicweb.devtools.fill import ValueGenerator

import random


def random_numbers(size):
    return u''.join(random.choice('0123456789') for i in range(size))


class MyValueGenerator(ValueGenerator):
    def generate_Book_isbn10(self, entity, index):
        return random_numbers(10)

    def generate_Book_isbn13(self, entity, index):
        return random_numbers(13)


class AutomaticWebTest(AutomaticWebTest):

    def to_test_etypes(self):
        return set(('Book', 'Collection', 'Editor'))

    def list_startup_views(self):
        return ()


class ViewTC(WebCWTC):

    def test_author_view(self):
        with self.admin_access.web_request() as req:
            jdoe = req.create_entity('Person', surname=u'jdoe')
            req.create_entity('Book', title=u'book', authors=jdoe)
            # should not raise
            jdoe.view('author-biblio')


if __name__ == '__main__':
    import unittest
    unittest.main()
